@@ -29,7 +29,7 @@ from nox._resolver import CycleError
 from nox._version import InvalidVersionSpecifier, VersionCheckFailed, check_nox_version
 from nox.logger import logger
 from nox.manifest import WARN_PYTHONS_IGNORED, Manifest
-from nox.sessions import Result, Status
+from nox.sessions import Result, Status, _duration_str
 
 if TYPE_CHECKING:
     import types
@@ -408,14 +408,17 @@ def print_summary(
 
     # Iterate over the results and print the result for each in a
     # human-readable way.
-    logger.session_info("Ran multiple sessions:")
+    total_duration = sum(result.duration for result in results)
+    duration_str = _duration_str(total_duration, " in {time}")
+    logger.session_info(f"Ran {len(results)} sessions{duration_str}:")
     for result in results:
         name = result.session.friendly_name
         status = result.status.name.lower()
+        duration_str = _duration_str(result.duration, ", took {time}")
         if result.status is Status.SKIPPED and result.reason:
-            result.log(f"* {name}: {status} ({result.reason})")
+            result.log(f"* {name}: {status} ({result.reason}){duration_str}")
         else:
-            result.log(f"* {name}: {status}")
+            result.log(f"* {name}: {status}{duration_str}")
 
     # Return the results that were sent to this function.
     return results
